@@ -1,6 +1,6 @@
 /* GDB/Scheme exception support.
 
-   Copyright (C) 2014-2022 Free Software Foundation, Inc.
+   Copyright (C) 2014-2026 Free Software Foundation, Inc.
 
    This file is part of GDB.
 
@@ -28,7 +28,6 @@
    The non-static functions in this file have prefix gdbscm_ and
    not exscm_ on purpose.  */
 
-#include "defs.h"
 #include <signal.h>
 #include "guile-internal.h"
 
@@ -234,7 +233,7 @@ SCM
 gdbscm_make_type_error (const char *subr, int arg_pos, SCM bad_value,
 			const char *expected_type)
 {
-  char *msg;
+  gdb::unique_xmalloc_ptr<char> msg;
   SCM result;
 
   if (arg_pos > 0)
@@ -262,9 +261,8 @@ gdbscm_make_type_error (const char *subr, int arg_pos, SCM bad_value,
 	msg = xstrprintf (_("Wrong type argument: ~S"));
     }
 
-  result = gdbscm_make_error (scm_arg_type_key, subr, msg,
+  result = gdbscm_make_error (scm_arg_type_key, subr, msg.get (),
 			      scm_list_1 (bad_value), scm_list_1 (bad_value));
-  xfree (msg);
   return result;
 }
 
@@ -279,7 +277,7 @@ static SCM
 gdbscm_make_arg_error (SCM key, const char *subr, int arg_pos, SCM bad_value,
 		       const char *error_prefix, const char *error)
 {
-  char *msg;
+  gdb::unique_xmalloc_ptr<char> msg;
   SCM result;
 
   if (error_prefix != NULL)
@@ -300,9 +298,8 @@ gdbscm_make_arg_error (SCM key, const char *subr, int arg_pos, SCM bad_value,
 	msg = xstrprintf (_("%s: ~S"), error);
     }
 
-  result = gdbscm_make_error (key, subr, msg,
-			      scm_list_1 (bad_value), scm_list_1 (bad_value));
-  xfree (msg);
+  result = gdbscm_make_error (key, subr, msg.get (), scm_list_1 (bad_value),
+			      scm_list_1 (bad_value));
   return result;
 }
 
