@@ -1,6 +1,6 @@
 /* Register offsets for HPPA running GNU/Linux.
 
-   Copyright (C) 2007-2022 Free Software Foundation, Inc.
+   Copyright (C) 2007-2026 Free Software Foundation, Inc.
 
    This file is part of GDB.
 
@@ -17,8 +17,8 @@
    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
 
-#ifndef HPPA_LINUX_OFFSETS_H
-#define HPPA_LINUX_OFFSETS_H
+#ifndef GDB_HPPA_LINUX_OFFSETS_H
+#define GDB_HPPA_LINUX_OFFSETS_H
 
 #define PT_PSW offsetof(struct pt_regs, gr[ 0])
 #define PT_GR1 offsetof(struct pt_regs, gr[ 1])
@@ -105,4 +105,4 @@
 #define PT_ISR offsetof(struct pt_regs, isr)
 #define PT_IOR offsetof(struct pt_regs, ior)
 
-#endif /* HPPA_LINUX_OFFSETS_H */
+#endif /* GDB_HPPA_LINUX_OFFSETS_H */
